==> zio-aws-redshift_2.12-5.17.160.1-sources.jar: zio/aws/redshift/model/ModifyScheduledActionResponse.scala <==
package zio.aws.redshift.model
import zio.aws.redshift.model.primitives.TStamp
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class ModifyScheduledActionResponse(
    scheduledActionName: Option[String] = None,
    targetAction: Option[zio.aws.redshift.model.ScheduledActionType] = None,
    schedule: Option[String] = None,
    iamRole: Option[String] = None,
    scheduledActionDescription: Option[String] = None,
    state: Option[zio.aws.redshift.model.ScheduledActionState] = None,
    nextInvocations: Option[Iterable[TStamp]] = None,
    startTime: Option[TStamp] = None,
    endTime: Option[TStamp] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.ModifyScheduledActionResponse = {
    import ModifyScheduledActionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.ModifyScheduledActionResponse
      .builder()
      .optionallyWith(
        scheduledActionName.map(value => value: java.lang.String)
      )(_.scheduledActionName)
      .optionallyWith(targetAction.map(value => value.buildAwsValue()))(
        _.targetAction
      )
      .optionallyWith(schedule.map(value => value: java.lang.String))(
        _.schedule
      )
      .optionallyWith(iamRole.map(value => value: java.lang.String))(_.iamRole)
      .optionallyWith(
        scheduledActionDescription.map(value => value: java.lang.String)
      )(_.scheduledActionDescription)
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(
        nextInvocations.map(value =>
          value.map { item =>
            TStamp.unwrap(item): Instant
          }.asJavaCollection
        )
      )(_.nextInvocations)
      .optionallyWith(startTime.map(value => TStamp.unwrap(value): Instant))(
        _.startTime
      )
      .optionallyWith(endTime.map(value => TStamp.unwrap(value): Instant))(
        _.endTime
      )
      .build()
  }
  def asReadOnly
      : zio.aws.redshift.model.ModifyScheduledActionResponse.ReadOnly =
    zio.aws.redshift.model.ModifyScheduledActionResponse.wrap(buildAwsValue())
}
object ModifyScheduledActionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.ModifyScheduledActionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.ModifyScheduledActionResponse =
      zio.aws.redshift.model.ModifyScheduledActionResponse(
        scheduledActionName.map(value => value),
        targetAction.map(value => value.asEditable),
        schedule.map(value => value),
        iamRole.map(value => value),
        scheduledActionDescription.map(value => value),
        state.map(value => value),
        nextInvocations.map(value => value),
        startTime.map(value => value),
        endTime.map(value => value)
      )
    def scheduledActionName: Option[String]
    def targetAction
        : Option[zio.aws.redshift.model.ScheduledActionType.ReadOnly]
    def schedule: Option[String]
    def iamRole: Option[String]
    def scheduledActionDescription: Option[String]
    def state: Option[zio.aws.redshift.model.ScheduledActionState]
    def nextInvocations: Option[List[TStamp]]
    def startTime: Option[TStamp]
    def endTime: Option[TStamp]
    def getScheduledActionName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("scheduledActionName", scheduledActionName)
    def getTargetAction: ZIO[
      Any,
      AwsError,
      zio.aws.redshift.model.ScheduledActionType.ReadOnly
    ] = AwsError.unwrapOptionField("targetAction", targetAction)
    def getSchedule: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("schedule", schedule)
    def getIamRole: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("iamRole", iamRole)
    def getScheduledActionDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "scheduledActionDescription",
        scheduledActionDescription
      )
    def getState
        : ZIO[Any, AwsError, zio.aws.redshift.model.ScheduledActionState] =
      AwsError.unwrapOptionField("state", state)
    def getNextInvocations: ZIO[Any, AwsError, List[TStamp]] =
      AwsError.unwrapOptionField("nextInvocations", nextInvocations)
    def getStartTime: ZIO[Any, AwsError, TStamp] =
      AwsError.unwrapOptionField("startTime", startTime)
    def getEndTime: ZIO[Any, AwsError, TStamp] =
      AwsError.unwrapOptionField("endTime", endTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.ModifyScheduledActionResponse
  ) extends zio.aws.redshift.model.ModifyScheduledActionResponse.ReadOnly {
    override val scheduledActionName: Option[String] =
      scala.Option(impl.scheduledActionName()).map(value => value: String)
    override val targetAction
        : Option[zio.aws.redshift.model.ScheduledActionType.ReadOnly] = scala
      .Option(impl.targetAction())
      .map(value => zio.aws.redshift.model.ScheduledActionType.wrap(value))
    override val schedule: Option[String] =
      scala.Option(impl.schedule()).map(value => value: String)
    override val iamRole: Option[String] =
      scala.Option(impl.iamRole()).map(value => value: String)
    override val scheduledActionDescription: Option[String] = scala
      .Option(impl.scheduledActionDescription())
      .map(value => value: String)
    override val state: Option[zio.aws.redshift.model.ScheduledActionState] =
      scala
        .Option(impl.state())
        .map(value => zio.aws.redshift.model.ScheduledActionState.wrap(value))
    override val nextInvocations: Option[List[TStamp]] = scala
      .Option(impl.nextInvocations())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.redshift.model.primitives.TStamp(item)
        }.toList
      )
    override val startTime: Option[TStamp] = scala
      .Option(impl.startTime())
      .map(value => zio.aws.redshift.model.primitives.TStamp(value))
    override val endTime: Option[TStamp] = scala
      .Option(impl.endTime())
      .map(value => zio.aws.redshift.model.primitives.TStamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.ModifyScheduledActionResponse
  ): zio.aws.redshift.model.ModifyScheduledActionResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-redshift_2.13-5.17.239.1-sources.jar: zio/aws/redshift/model/ModifyScheduledActionResponse.scala <==
package zio.aws.redshift.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.redshift.model.primitives.TStamp
import scala.jdk.CollectionConverters._
final case class ModifyScheduledActionResponse(
    scheduledActionName: Optional[String] = Optional.Absent,
    targetAction: Optional[zio.aws.redshift.model.ScheduledActionType] =
      Optional.Absent,
    schedule: Optional[String] = Optional.Absent,
    iamRole: Optional[String] = Optional.Absent,
    scheduledActionDescription: Optional[String] = Optional.Absent,
    state: Optional[zio.aws.redshift.model.ScheduledActionState] =
      Optional.Absent,
    nextInvocations: Optional[Iterable[TStamp]] = Optional.Absent,
    startTime: Optional[TStamp] = Optional.Absent,
    endTime: Optional[TStamp] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.ModifyScheduledActionResponse = {
    import ModifyScheduledActionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.ModifyScheduledActionResponse
      .builder()
      .optionallyWith(
        scheduledActionName.map(value => value: java.lang.String)
      )(_.scheduledActionName)
      .optionallyWith(targetAction.map(value => value.buildAwsValue()))(
        _.targetAction
      )
      .optionallyWith(schedule.map(value => value: java.lang.String))(
        _.schedule
      )
      .optionallyWith(iamRole.map(value => value: java.lang.String))(_.iamRole)
      .optionallyWith(
        scheduledActionDescription.map(value => value: java.lang.String)
      )(_.scheduledActionDescription)
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(
        nextInvocations.map(value =>
          value.map { item =>
            TStamp.unwrap(item): Instant
          }.asJavaCollection
        )
      )(_.nextInvocations)
      .optionallyWith(startTime.map(value => TStamp.unwrap(value): Instant))(
        _.startTime
      )
      .optionallyWith(endTime.map(value => TStamp.unwrap(value): Instant))(
        _.endTime
      )
      .build()
  }
  def asReadOnly
      : zio.aws.redshift.model.ModifyScheduledActionResponse.ReadOnly =
    zio.aws.redshift.model.ModifyScheduledActionResponse.wrap(buildAwsValue())
}
object ModifyScheduledActionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.ModifyScheduledActionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.ModifyScheduledActionResponse =
      zio.aws.redshift.model.ModifyScheduledActionResponse(
        scheduledActionName.map(value => value),
        targetAction.map(value => value.asEditable),
        schedule.map(value => value),
        iamRole.map(value => value),
        scheduledActionDescription.map(value => value),
        state.map(value => value),
        nextInvocations.map(value => value),
        startTime.map(value => value),
        endTime.map(value => value)
      )
    def scheduledActionName: Optional[String]
    def targetAction
        : Optional[zio.aws.redshift.model.ScheduledActionType.ReadOnly]
    def schedule: Optional[String]
    def iamRole: Optional[String]
    def scheduledActionDescription: Optional[String]
    def state: Optional[zio.aws.redshift.model.ScheduledActionState]
    def nextInvocations: Optional[List[TStamp]]
    def startTime: Optional[TStamp]
    def endTime: Optional[TStamp]
    def getScheduledActionName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("scheduledActionName", scheduledActionName)
    def getTargetAction: ZIO[
      Any,
      AwsError,
      zio.aws.redshift.model.ScheduledActionType.ReadOnly
    ] = AwsError.unwrapOptionField("targetAction", targetAction)
    def getSchedule: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("schedule", schedule)
    def getIamRole: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("iamRole", iamRole)
    def getScheduledActionDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "scheduledActionDescription",
        scheduledActionDescription
      )
    def getState
        : ZIO[Any, AwsError, zio.aws.redshift.model.ScheduledActionState] =
      AwsError.unwrapOptionField("state", state)
    def getNextInvocations: ZIO[Any, AwsError, List[TStamp]] =
      AwsError.unwrapOptionField("nextInvocations", nextInvocations)
    def getStartTime: ZIO[Any, AwsError, TStamp] =
      AwsError.unwrapOptionField("startTime", startTime)
    def getEndTime: ZIO[Any, AwsError, TStamp] =
      AwsError.unwrapOptionField("endTime", endTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.ModifyScheduledActionResponse
  ) extends zio.aws.redshift.model.ModifyScheduledActionResponse.ReadOnly {
    override val scheduledActionName: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.scheduledActionName())
      .map(value => value: String)
    override val targetAction
        : Optional[zio.aws.redshift.model.ScheduledActionType.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.targetAction())
        .map(value => zio.aws.redshift.model.ScheduledActionType.wrap(value))
    override val schedule: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.schedule())
      .map(value => value: String)
    override val iamRole: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.iamRole())
      .map(value => value: String)
    override val scheduledActionDescription: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.scheduledActionDescription())
        .map(value => value: String)
    override val state: Optional[zio.aws.redshift.model.ScheduledActionState] =
      zio.aws.core.internal
        .optionalFromNullable(impl.state())
        .map(value => zio.aws.redshift.model.ScheduledActionState.wrap(value))
    override val nextInvocations: Optional[List[TStamp]] = zio.aws.core.internal
      .optionalFromNullable(impl.nextInvocations())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.redshift.model.primitives.TStamp(item)
        }.toList
      )
    override val startTime: Optional[TStamp] = zio.aws.core.internal
      .optionalFromNullable(impl.startTime())
      .map(value => zio.aws.redshift.model.primitives.TStamp(value))
    override val endTime: Optional[TStamp] = zio.aws.core.internal
      .optionalFromNullable(impl.endTime())
      .map(value => zio.aws.redshift.model.primitives.TStamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.ModifyScheduledActionResponse
  ): zio.aws.redshift.model.ModifyScheduledActionResponse.ReadOnly =
    new Wrapper(impl)
}
